@@ -22,6 +22,12 @@ const (
 	// APIVersionSelector is the CUE path for the Timoni's API version.
 	APIVersionSelector Selector = "timoni.apiVersion"
 
+	// InstanceSelector is the CUE path for the Timoni's instance.
+	InstanceSelector Selector = "timoni.instance"
+
+	// ConfigValuesSelector is the CUE path for the Timoni's instance config.
+	ConfigValuesSelector Selector = "timoni.instance.config"
+
 	// ApplySelector is the CUE path for the Timoni's apply resource sets.
 	ApplySelector Selector = "timoni.apply"
 
@@ -50,9 +56,8 @@ type Instance struct {
 	// Module is a reference to the module's artifact in the registry.
 	Module ModuleReference `json:"module"`
 
-	// Values is the module configuration.
-	// +optional
-	Values string `json:"values,omitempty"`
+	// Values hold the user-supplied configuration of this instance.
+	Values string `json:"values"`
 
 	// LastTransitionTime is the timestamp (UTC RFC3339) of the last inventory change.
 	// +optional
@@ -61,4 +66,8 @@ type Instance struct {
 	// Inventory contains the list of Kubernetes resource object references.
 	// +optional
 	Inventory *ResourceInventory `json:"inventory,omitempty"`
+
+	// Images contains the list of container image references.
+	// +optional
+	Images []string `json:"images,omitempty"`
 }
